@@ -402,6 +402,24 @@ typedef struct _MOS_NULL_RENDERING_FLAGS {
     };
 } MOS_NULL_RENDERING_FLAGS;
 
+//!
+//! \brief Native Fence report Flags
+//!
+typedef struct _NATIVE_FENCE_MODE_REPORT_FLAGS
+{
+    union
+    {
+        struct
+        {
+            uint32_t Disabled : 1;
+            uint32_t SyncByCmd : 1;
+            uint32_t SyncByAPI : 1;
+        };
+        uint32_t Value;
+    };
+} NATIVE_FENCE_MODE_REPORT_FLAGS;
+
+
 //!
 //! \brief GPU Context definitions
 //!
@@ -512,6 +530,7 @@ enum MOS_COMPONENT
     COMPONENT_MEMDECOMP,
     COMPONENT_MCPY,
     COMPONENT_OCA,
+    COMPONENT_MOS,
 };
 C_ASSERT(COMPONENT_OCA == 11);  // When adding, update assert
 
