@@ -102,7 +102,7 @@ uint32_t CodechalEncHevcState::GetPicHdrSize()
                     zeroCount = 0;
                 }
 
-                *hdrPtr++;
+                hdrPtr++;
             }
         }
 
@@ -215,6 +215,44 @@ MOS_STATUS CodechalEncHevcState::SetPictureStructs()
         return eStatus;
     }
 
+        // Set min/max QP values based on frame type if atleast one of them is non-zero
+    if (m_hevcPicParams->BRCMinQp || m_hevcPicParams->BRCMaxQp)
+    {
+        m_minMaxQpControlEnabled = true;
+        if (m_hevcPicParams->CodingType == I_TYPE)
+        {
+            m_maxQpForI = MOS_MIN(MOS_MAX(m_hevcPicParams->BRCMaxQp, 1), 51);           // Clamp to the max QP to [1, 51] . Zero is not used by our Kernel.
+            m_minQpForI = MOS_MIN(MOS_MAX(m_hevcPicParams->BRCMinQp, 1), m_maxQpForI);  // Clamp the min QP to [1, maxQP] to make sure minQP <= maxQP
+            if (!m_minMaxQpControlForP)
+            {
+                m_minQpForP = m_minQpForI;
+                m_maxQpForP = m_maxQpForI;
+            }
+            if (!m_minMaxQpControlForB)
+            {
+                m_minQpForB = m_minQpForI;
+                m_maxQpForB = m_maxQpForI;
+            }
+        }
+        else if (m_hevcPicParams->CodingType == P_TYPE)
+        {
+            m_minMaxQpControlForP = true;
+            m_maxQpForP           = MOS_MIN(MOS_MAX(m_hevcPicParams->BRCMaxQp, 1), 51);           // Clamp to the max QP to [1, 51]. Zero is not used by our Kernel.
+            m_minQpForP           = MOS_MIN(MOS_MAX(m_hevcPicParams->BRCMinQp, 1), m_maxQpForP);  // Clamp the min QP to [1, maxQP] to make sure minQP <= maxQP
+            if (!m_minMaxQpControlForB)
+            {
+                m_minQpForB = m_minQpForP;
+                m_maxQpForB = m_maxQpForP;
+            }
+        }
+        else if (m_hevcPicParams->CodingType == B_TYPE)
+        {
+            m_minMaxQpControlForB = true;
+            m_maxQpForB           = MOS_MIN(MOS_MAX(m_hevcPicParams->BRCMaxQp, 1), 51);           // Clamp to the max QP to [1, 51]. Zero is not used by our Kernel.
+            m_minQpForB           = MOS_MIN(MOS_MAX(m_hevcPicParams->BRCMinQp, 1), m_maxQpForB);  // Clamp the min QP to [1, maxQP] to make sure minQP <= maxQP
+        }
+    }
+
     // CQP with Fast Surveillance [Distortion Surface needs to be allocated]
     if (m_brcEnabled || m_hevcSeqParams->bVideoSurveillance || m_cqpEnabled)
     {
@@ -223,8 +261,8 @@ MOS_STATUS CodechalEncHevcState::SetPictureStructs()
 
     if (m_brcEnabled)
     {
-        // For ICQ mode, ignore BRCPrecision sent by the app and set the number of passes internally
-        if (m_hevcSeqParams->RateControlMethod == RATECONTROL_ICQ)
+        // For ICQ mode or when min/max QP used, ignore BRCPrecision sent by the app and set the number of passes internally
+        if ((m_hevcSeqParams->RateControlMethod == RATECONTROL_ICQ) || (m_minMaxQpControlEnabled))
         {
             m_numPasses = 0;  // no IPCM for HEVC
         }
@@ -400,6 +438,7 @@ MOS_STATUS CodechalEncHevcState::ExecutePictureLevel()
             &miConditionalBatchBufferEndParams));
 
         auto mmioRegisters = m_hcpInterface->GetMmioRegisters(m_vdboxIndex);
+        CODECHAL_ENCODE_CHK_NULL_RETURN(mmioRegisters);
         MHW_MI_STORE_REGISTER_MEM_PARAMS miStoreRegMemParams;
         MHW_MI_COPY_MEM_MEM_PARAMS miCpyMemMemParams;
         // Write back the HCP image control register for RC6 may clean it out
@@ -430,13 +469,14 @@ MOS_STATUS CodechalEncHevcState::ExecutePictureLevel()
         // of the BB and keep the current frame's tag at the end of the BB. There will be a delay for tag update but it should be fine
         // as long as Dec/VP/Enc won't depend on this PAK so soon.
 
-        MOS_RESOURCE globalGpuContextSyncTagBuffer;
+        PMOS_RESOURCE globalGpuContextSyncTagBuffer = nullptr;
         CODECHAL_ENCODE_CHK_STATUS_RETURN(m_osInterface->pfnGetGpuStatusBufferResource(
             m_osInterface,
-            &globalGpuContextSyncTagBuffer));
+            globalGpuContextSyncTagBuffer));
+        CODECHAL_ENCODE_CHK_NULL_RETURN(globalGpuContextSyncTagBuffer);
 
         MHW_MI_STORE_DATA_PARAMS params;
-        params.pOsResource = &globalGpuContextSyncTagBuffer;
+        params.pOsResource = globalGpuContextSyncTagBuffer;
         params.dwResourceOffset = m_osInterface->pfnGetGpuStatusTagOffset(m_osInterface, m_osInterface->CurrentGpuContextOrdinal);
         uint32_t value = m_osInterface->pfnGetGpuStatusTag(m_osInterface, m_osInterface->CurrentGpuContextOrdinal);
         params.dwValue = (value > 0) ? (value - 1) : 0;
@@ -922,7 +962,7 @@ MOS_STATUS CodechalEncHevcState::UserFeatureKeyReport()
 
     CODECHAL_ENCODE_CHK_STATUS_RETURN(CodechalEncodeHevcBase::UserFeatureKeyReport());
 
-    CodecHalEncode_WriteKey(__MEDIA_USER_FEATURE_VALUE_HEVC_ENCODE_REGION_NUMBER_ID, m_numRegionsInSlice);
+    CodecHalEncode_WriteKey(__MEDIA_USER_FEATURE_VALUE_HEVC_ENCODE_REGION_NUMBER_ID, m_numRegionsInSlice, m_osInterface->pOsContext);
 
     return eStatus;
 }
@@ -1027,7 +1067,11 @@ CodechalEncHevcState::CodechalEncHevcState(
 
 CodechalEncHevcState::~CodechalEncHevcState()
 {
-    MOS_Delete(m_hmeKernel);
+    if (m_hmeKernel)
+    {
+        MOS_Delete(m_hmeKernel);
+        m_hmeKernel = nullptr;
+    }
 }
 
 MOS_STATUS CodechalEncHevcState::AllocateBrcResources()
@@ -1288,7 +1332,7 @@ MOS_STATUS CodechalEncHevcState::AllocateBrcResources()
         width,
         height,
         "ROI Buffer"));
-
+    
     return eStatus;
 }
 
@@ -1476,7 +1520,7 @@ MOS_STATUS CodechalEncHevcState::GetFrameBrcLevel()
         // LDB
         if (m_pictureCodingType == I_TYPE)
         {
-            if (m_hevcPicParams->FrameLevel == 0)
+            if (m_hevcSeqParams->HierarchicalFlag > 0 || m_hevcPicParams->HierarchLevelPlus1 == 0)
             {
                 m_currFrameBrcLevel = HEVC_BRC_FRAME_TYPE_I;
             }
@@ -1488,19 +1532,19 @@ MOS_STATUS CodechalEncHevcState::GetFrameBrcLevel()
         }
         else if ((m_pictureCodingType == P_TYPE) || (m_pictureCodingType == B_TYPE))
         {
-            if (m_hevcPicParams->FrameLevel == 0)
+            if (m_hevcPicParams->HierarchLevelPlus1 == 0)
             {
                 m_currFrameBrcLevel = HEVC_BRC_FRAME_TYPE_P_OR_LB;
             }
-            else if (m_hevcPicParams->FrameLevel == 1)
+            else if (m_hevcPicParams->HierarchLevelPlus1 == 1)
             {
                 m_currFrameBrcLevel = HEVC_BRC_FRAME_TYPE_B;
             }
-            else if (m_hevcPicParams->FrameLevel == 2)
+            else if (m_hevcPicParams->HierarchLevelPlus1 == 2)
             {
                 m_currFrameBrcLevel = HEVC_BRC_FRAME_TYPE_B1;
             }
-            else if (m_hevcPicParams->FrameLevel == 3)
+            else if (m_hevcPicParams->HierarchLevelPlus1 == 3)
             {
                 CODECHAL_ENCODE_ASSERTMESSAGE("FrameLevel 3 is not supported for LDB\n");
                 return MOS_STATUS_INVALID_PARAMETER;
@@ -1729,7 +1773,7 @@ MOS_STATUS CodechalEncHevcState::SetupROISurface()
         return eStatus;
     }
 
-    uint32_t bufferWidthInByte = MOS_ALIGN_CEIL((m_downscaledWidthInMb4x << 4), 64);
+    uint32_t bufferWidthInByte  = m_brcBuffers.sBrcRoiSurface.dwPitch;
     uint32_t bufferHeightInByte = MOS_ALIGN_CEIL((m_downscaledHeightInMb4x << 2), 8);
     uint32_t numMBs = m_picWidthInMb * m_picHeightInMb;
     for (uint32_t uMB = 0; uMB <= numMBs; uMB++)
@@ -1798,3 +1842,71 @@ MOS_STATUS CodechalEncHevcState::SetupROISurface()
 
     return eStatus;
 }
+
+MOS_STATUS CodechalEncHevcState::GetRoundingIntraInterToUse()
+{
+    MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
+
+    CODECHAL_ENCODE_FUNCTION_ENTER;
+
+    if (m_hevcPicParams->CustomRoundingOffsetsParams.fields.EnableCustomRoudingIntra)
+    {
+        m_roundingIntraInUse = m_hevcPicParams->CustomRoundingOffsetsParams.fields.RoundingOffsetIntra;
+    }
+    else
+    {
+        if (m_hevcSeqParams->NumOfBInGop[1] != 0 || m_hevcSeqParams->NumOfBInGop[2] != 0)
+        {
+            //Hierachical B GOP
+            if (m_hevcPicParams->CodingType == I_TYPE || 
+                m_hevcPicParams->CodingType == P_TYPE)
+            {
+                m_roundingIntraInUse = 4;
+            }
+            else if (m_hevcPicParams->CodingType == B_TYPE)
+            {
+                m_roundingIntraInUse = 3;
+            }
+            else
+            {
+                m_roundingIntraInUse = 2;
+            }
+        }
+        else
+        {
+            m_roundingIntraInUse = 10;
+        }
+    }
+
+    if (m_hevcPicParams->CustomRoundingOffsetsParams.fields.EnableCustomRoudingInter)
+    {
+        m_roundingInterInUse = m_hevcPicParams->CustomRoundingOffsetsParams.fields.RoundingOffsetInter;
+    }
+    else
+    {
+        if (m_hevcSeqParams->NumOfBInGop[1] != 0 || m_hevcSeqParams->NumOfBInGop[2] != 0)
+        {
+            //Hierachical B GOP 
+            if (m_hevcPicParams->CodingType == I_TYPE || 
+                m_hevcPicParams->CodingType == P_TYPE)
+            {
+                m_roundingInterInUse = 4;
+            }
+            else if (m_hevcPicParams->CodingType == B_TYPE)
+            {
+                m_roundingInterInUse = 3;
+            }
+            else
+            {
+                m_roundingInterInUse = 2;
+            }
+        }
+        else
+        {
+            m_roundingInterInUse = 4;
+        }
+    }
+
+    return eStatus;
+}
+
