@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2017, Intel Corporation
+* Copyright (c) 2017-2021, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -56,6 +56,7 @@
 #define CODECHAL_ENCODE_VP9_PIC_STATE_BUFFER_SIZE_PER_PASS      192 // 42 DWORDs for Pic State one uint32_t for BB End + 5 uint32_tS reserved to make it aligned for kernel read
 #define CODECHAL_ENCODE_VP9_MIN_TILE_SIZE_WIDTH                 256
 #define CODECHAL_ENCODE_VP9_MIN_TILE_SIZE_HEIGHT                128
+#define CODECHAL_ENCODE_VP9_NUM_MAX_L0_REF                      3
 #define CODECHAL_ENCODE_VP9_HUC_SUPERFRAME_PASS                 2
 #define CODECHAL_ENCODE_VP9_REF_SEGMENT_DISABLED                0xFF
 #define CODECHAL_ENCODE_VP9_BRC_MAX_NUM_OF_PASSES               4
@@ -66,9 +67,10 @@
 #define CODECHAL_ENCODE_VP9_SEGMENT_STATE_BUFFER_SIZE           256
 #define CODECHAL_ENCODE_VP9_BRC_BITSTREAM_SIZE_BUFFER_SIZE      16
 #define CODECHAL_ENCODE_VP9_BRC_MSDK_PAK_BUFFER_SIZE            64
-#define __MEDIA_USER_FEATURE_VALUE_VP9_ENCODE_ENABLE_BRC_DLL                 5158
-#define __MEDIA_USER_FEATURE_VALUE_VP9_ENCODE_BRC_DLL_PATH                   5159
-#define __MEDIA_USER_FEATURE_VALUE_VP9_ENCODE_ENABLE_BRC_DLL_CUSTOMPATH      5160
+#define CODECHAL_VDENC_VP9_BRC_HUC_STATUS_ERROR_MASK                     (1 << 30)
+#define CODECHAL_VDENC_VP9_BRC_HUC_STATUS_ARITHMETIC_OVERFLOW_ERROR_MASK (1 << 27)
+#define CODECHAL_VDENC_VP9_BRC_HUC_STATUS_MEMORY_ACCESS_ERROR_MASK       (1 << 26)
+#define CODECHAL_VDENC_VP9_BRC_HUC_STATUS_DMEM_ERROR_MASK                (1 << 24)
 
 #define VP9SWBRCLIB  "VP9BRCDLL.dll"
 
@@ -82,8 +84,7 @@ typedef struct _HUC_AUX_BUFFER
     uint8_t  rsvd3;
     uint32_t RSVD[13];
 } HUC_AUX_BUFFER, *PHUC_AUX_BUFFER;
-#define CODECHAL_ENCODE_VP9_FRAME_HEADER_SIZE                   4096
-#define CODECHAL_ENCODE_VP9_MAX_NAL_UNIT_TYPE                   1   // only support one NAL unit for uncompressed header
+
 #define ENCODE_VP9_8K_PIC_WIDTH     8192
 #define ENCODE_VP9_8K_PIC_HEIGHT    8192
 #define ENCODE_VP9_16K_PIC_WIDTH     16384
@@ -396,7 +397,7 @@ public:
     struct HucBrcBuffers
     {
         MOS_RESOURCE           resBrcHistoryBuffer;
-        MOS_RESOURCE           resBrcConstantDataBuffer;
+        MOS_RESOURCE           resBrcConstantDataBuffer[2]; // 0 == I, 1 == P
         MOS_RESOURCE           resBrcMsdkPakBuffer;
         MOS_RESOURCE           resBrcMbEncCurbeWriteBuffer;
         MOS_RESOURCE           resMbEncAdvancedDsh;
@@ -1635,8 +1636,8 @@ public:
     PCODEC_VP9_ENCODE_PIC_PARAMS      m_vp9PicParams     = nullptr;  //!< Pointer to picture parameters
     PCODEC_VP9_ENCODE_SEGMENT_PARAMS  m_vp9SegmentParams = nullptr;  //!< Pointer to segment parameters
 
-    CODEC_PIC_ID                                m_picIdx[CODEC_VP9_NUM_REF_FRAMES];
-    PCODEC_REF_LIST                             m_refList[m_numUncompressedSurface];
+    CODEC_PIC_ID                                m_picIdx[CODEC_VP9_NUM_REF_FRAMES] = {};
+    PCODEC_REF_LIST                             m_refList[m_numUncompressedSurface] = {};
     PCODECHAL_NAL_UNIT_PARAMS*                  m_nalUnitParams = nullptr;
     uint32_t                                    m_numNalUnit = 0;
 
@@ -1695,10 +1696,10 @@ public:
 
     bool                                        m_hucEnabled = false;
     bool                                        m_segmentMapAllocated = false;
-    MOS_RESOURCE                                m_resHucProbDmemBuffer[3];
+    MOS_RESOURCE                                m_resHucProbDmemBuffer[3][CODECHAL_ENCODE_RECYCLED_BUFFER_NUM];
     MOS_RESOURCE                                m_resHucDefaultProbBuffer;
     MOS_RESOURCE                                m_resHucProbOutputBuffer;
-    MOS_RESOURCE                                m_resHucPakInsertUncompressedHeaderReadBuffer;
+    MOS_RESOURCE                                m_resHucPakInsertUncompressedHeaderReadBuffer[CODECHAL_ENCODE_RECYCLED_BUFFER_NUM];
     MOS_RESOURCE                                m_resHucPakInsertUncompressedHeaderWriteBuffer;
     MOS_RESOURCE                                m_resHucPakMmioBuffer;
     MOS_RESOURCE                                m_resHucDebugOutputBuffer;
@@ -1713,7 +1714,7 @@ public:
     MOS_SURFACE                                 m_4xMeDistortionBuffer;
 
     // BRC
-    HucBrcBuffers                               m_brcBuffers;
+    HucBrcBuffers                               m_brcBuffers = {};
 
     // DYS
     MHW_KERNEL_STATE                            m_dysKernelState;
@@ -1761,7 +1762,7 @@ public:
     uint16_t                                    m_vdencPictureState2ndLevelBBIndex = 0;
     MOS_RESOURCE                                m_resVdencDysPictureState2NdLevelBatchBuffer;
     MOS_RESOURCE                                m_resVdencBrcInitDmemBuffer;
-    MOS_RESOURCE                                m_resVdencBrcUpdateDmemBuffer[3];
+    MOS_RESOURCE                                m_resVdencBrcUpdateDmemBuffer[3][CODECHAL_VP9_ENCODE_RECYCLED_BUFFER_NUM];
     MOS_RESOURCE                                m_resVdencDataExtensionBuffer;
     CODECHAL_ENCODE_BUFFER                      m_resPakcuLevelStreamoutData;
     CODECHAL_ENCODE_BUFFER                      m_resPakSliceLevelStreamutData;
@@ -1773,6 +1774,8 @@ public:
     uint32_t                                    m_sizeOfSseSrcPixelRowStoreBufferPerLcu = 0;
     PCODECHAL_CMD_INITIALIZER                   m_hucCmdInitializer = nullptr;
 
+    bool                                        m_initBrcConstantDataBuffer = false;
+
 protected:
     //!
     //! \brief    Constructor
@@ -1895,7 +1898,7 @@ public:
     //! \brief      User feature key report
     //!
     //! \return     MOS_STATUS
-    //!             MOS_STATUS_SUCCESS if success, else fail reason 
+    //!             MOS_STATUS_SUCCESS if success, else fail reason
     //!
     MOS_STATUS UserFeatureKeyReport();
 
@@ -1906,7 +1909,7 @@ public:
     //!            Pointer to command buffer
     //!
     //! \return   MOS_STATUS
-    //!           MOS_STATUS_SUCCESS if success, else fail reason 
+    //!           MOS_STATUS_SUCCESS if success, else fail reason
     //!
     MOS_STATUS ReadHcpStatus(
         PMOS_COMMAND_BUFFER cmdBuffer);
@@ -1918,7 +1921,7 @@ public:
     //! \brief      Construct super frame
     //!
     //! \return     MOS_STATUS
-    //!             MOS_STATUS_SUCCESS if success, else fail reason 
+    //!             MOS_STATUS_SUCCESS if success, else fail reason
     //!
     MOS_STATUS ConstructSuperFrame();
 
@@ -1926,18 +1929,33 @@ public:
     //! \brief      Set dmem HuC Vp9 Prob
     //!
     //! \return     MOS_STATUS
-    //!             MOS_STATUS_SUCCESS if success, else fail reason 
+    //!             MOS_STATUS_SUCCESS if success, else fail reason
     //!
-    MOS_STATUS SetDmemHuCVp9Prob();
+    virtual MOS_STATUS SetDmemHuCVp9Prob();
 
     //!
     //! \brief      Store HuC status to register 
     //!
     //! \return     MOS_STATUS
-    //!             MOS_STATUS_SUCCESS if success, else fail reason 
+    //!             MOS_STATUS_SUCCESS if success, else fail reason
     //!
     MOS_STATUS StoreHuCStatus2Register(PMOS_COMMAND_BUFFER cmdBuffer);
 
+    //!
+    //! \brief    Add store HUC_ERROR_STATUS register command in the command buffer
+    //!
+    //! \param    [in] mmioRegisters
+    //!           Pointer to mmio huc register
+    //! \param    [in] cmdBuffer
+    //!           Pointer to the command buffer
+    //! \param    [in] addToEnncodeStatus
+    //!           Flag to indicate whether huc error status will be stored in encode status buffer
+    //!
+    //! \return   MOS_STATUS
+    //!           MOS_STATUS_SUCCESS if success, else fail reason
+    //!
+    MOS_STATUS StoreHucErrorStatus(MmioRegistersHuc *mmioRegisters, PMOS_COMMAND_BUFFER cmdBuffer, bool addToEnncodeStatus);
+
     //!
     //! \brief     Init brc constant buffer
     //!
@@ -1947,12 +1965,16 @@ public:
     //!            Picture coding type
     //!
     //! \return    MOS_STATUS
-    //!            MOS_STATUS_SUCCESS if success, else fail reason 
+    //!            MOS_STATUS_SUCCESS if success, else fail reason
     //!
     MOS_STATUS InitBrcConstantBuffer(
         PMOS_RESOURCE brcConstResource,
         uint16_t pictureCodingType);
 
+    PMOS_RESOURCE GetBrcConstantBuffer(
+        PMOS_RESOURCE brcConstResource,
+        uint16_t pictureCodingType);
+
     //!
     //! \brief     Compute VD Encode BRC initQP
     //!
@@ -1962,7 +1984,7 @@ public:
     //!            Init QPP
     //!
     //! \return    MOS_STATUS
-    //!            MOS_STATUS_SUCCESS if success, else fail reason 
+    //!            MOS_STATUS_SUCCESS if success, else fail reason
     //!
     MOS_STATUS ComputeVDEncBRCInitQP(
         int32_t* initQpI,
@@ -1972,7 +1994,7 @@ public:
     //! \brief     Set dmem huc brc update
     //!
     //! \return    MOS_STATUS
-    //!            MOS_STATUS_SUCCESS if success, else fail reason 
+    //!            MOS_STATUS_SUCCESS if success, else fail reason
     //!
     MOS_STATUS SetDmemHuCBrcUpdate();
 
@@ -1980,7 +2002,7 @@ public:
     //! \brief     Set dmem huc brc init reset 
     //!
     //! \return    MOS_STATUS
-    //!            MOS_STATUS_SUCCESS if success, else fail reason 
+    //!            MOS_STATUS_SUCCESS if success, else fail reason
     //!
     MOS_STATUS SetDmemHuCBrcInitReset();
 
@@ -1991,7 +2013,7 @@ public:
     //!            Update status
     //!
     //! \return    MOS_STATUS
-    //!            MOS_STATUS_SUCCESS if success, else fail reason 
+    //!            MOS_STATUS_SUCCESS if success, else fail reason
     //!
     MOS_STATUS SoftwareBRC(bool update);
 
@@ -2008,7 +2030,7 @@ public:
     //!             Buffer pitch
     //!
     //! \return     uint32_t
-    //!             Return 0if call success, else -1 if fail 
+    //!             Return 0if call success, else -1 if fail
     //!
     uint32_t CalculateBufferOffset(
         uint32_t idx,
@@ -2023,7 +2045,7 @@ public:
     //!             Pointer to MOS surface
     //!
     //! \return     MOS_STATUS
-    //!             MOS_STATUS_SUCCESS if success, else fail reason 
+    //!             MOS_STATUS_SUCCESS if success, else fail reason
     //!
     MOS_STATUS PakConstructPicStateBatchBuf(
         PMOS_RESOURCE picStateBuffer);
@@ -2044,7 +2066,7 @@ public:
     //! \brief      Dys Reference frames
     //!
     //! \return     MOS_STATUS
-    //!             MOS_STATUS_SUCCESS if success, else fail reason 
+    //!             MOS_STATUS_SUCCESS if success, else fail reason
     //!
     MOS_STATUS DysRefFrames();
 
@@ -2055,7 +2077,7 @@ public:
     //!             Pointer to Dys sampler state parameters
     //!
     //! \return     MOS_STATUS
-    //!             MOS_STATUS_SUCCESS if success, else fail reason 
+    //!             MOS_STATUS_SUCCESS if success, else fail reason
     //!
     MOS_STATUS SetSamplerStateDys(
         DysSamplerStateParams* params);
@@ -2067,7 +2089,7 @@ public:
     //!             Pointer to Dys curbe parameters
     //!
     //! \return     MOS_STATUS
-    //!             MOS_STATUS_SUCCESS if success, else fail reason 
+    //!             MOS_STATUS_SUCCESS if success, else fail reason
     //!
     MOS_STATUS SetCurbeDys(
         DysCurbeParams* params);
@@ -2081,7 +2103,7 @@ public:
     //!             Pointer to Dys surface parameters
     //!
     //! \return     MOS_STATUS
-    //!             MOS_STATUS_SUCCESS if success, else fail reason 
+    //!             MOS_STATUS_SUCCESS if success, else fail reason
     //!
     MOS_STATUS SendDysSurfaces(
         PMOS_COMMAND_BUFFER cmdBuffer,
@@ -2094,7 +2116,7 @@ public:
     //!             Pointer to Dys kernel parameters
     //!
     //! \return     MOS_STATUS
-    //!             MOS_STATUS_SUCCESS if success, else fail reason 
+    //!             MOS_STATUS_SUCCESS if success, else fail reason
     //!
     virtual MOS_STATUS DysKernel(
         DysKernelParams*  dysKernelParams);
@@ -2106,7 +2128,7 @@ public:
     //!             Pointer to Vdenc vme state
     //!
     //! \return     MOS_STATUS
-    //!             MOS_STATUS_SUCCESS if success, else fail reason 
+    //!             MOS_STATUS_SUCCESS if success, else fail reason
     //!
     MOS_STATUS InitMEState(VdencVmeState* state);
 
@@ -2117,7 +2139,7 @@ public:
     //!             Pointer to Vdenc vme state
     //!
     //! \return     MOS_STATUS
-    //!             MOS_STATUS_SUCCESS if success, else fail reason 
+    //!             MOS_STATUS_SUCCESS if success, else fail reason
     //!
     MOS_STATUS VdencSetCurbeHmeKernel(
         VdencVmeState* state);
@@ -2146,7 +2168,7 @@ public:
     //!             Pointer to Vdenc vme state
     //!
     //! \return     MOS_STATUS
-    //!             MOS_STATUS_SUCCESS if success, else fail reason 
+    //!             MOS_STATUS_SUCCESS if success, else fail reason
     //!
     MOS_STATUS VdencHmeKernel(
         VdencVmeState* state);
@@ -2160,7 +2182,7 @@ public:
     //!             Pointer to MHW vdbox surface parameters
     //!
     //! \return     MOS_STATUS
-    //!             MOS_STATUS_SUCCESS if success, else fail reason 
+    //!             MOS_STATUS_SUCCESS if success, else fail reason
     //!
     void SetHcpDsSurfaceParams(MHW_VDBOX_SURFACE_PARAMS* dsSurfaceParams);
 
@@ -2171,7 +2193,7 @@ public:
     //!             Index of the surface
     //!
     //! \return     MOS_STATUS
-    //!             MOS_STATUS_SUCCESS if success, else fail reason 
+    //!             MOS_STATUS_SUCCESS if success, else fail reason
     //!
     MOS_STATUS Resize4x8xforDS(
         uint8_t bufIdx);
@@ -2191,7 +2213,7 @@ public:
     //!             Pointer to MOS surface
     //!
     //! \return     MOS_STATUS
-    //!             MOS_STATUS_SUCCESS if success, else fail reason 
+    //!             MOS_STATUS_SUCCESS if success, else fail reason
     //!
 
     MOS_STATUS SetHcpSrcSurfaceParams(MHW_VDBOX_SURFACE_PARAMS* surfaceParams,
@@ -2237,7 +2259,7 @@ public:
     //! \brief      Allocate resources brc
     //!
     //! \return     MOS_STATUS
-    //!             MOS_STATUS_SUCCESS if success, else fail reason 
+    //!             MOS_STATUS_SUCCESS if success, else fail reason
     //!
     MOS_STATUS AllocateResourcesBrc();
 
@@ -2259,7 +2281,7 @@ public:
     //!             Max level ratios
     //!
     //! \return     MOS_STATUS
-    //!             MOS_STATUS_SUCCESS if success, else fail reason 
+    //!             MOS_STATUS_SUCCESS if success, else fail reason
     //!
     MOS_STATUS CalculateTemporalRatios(
         uint16_t numberOfLayers,
@@ -2381,7 +2403,7 @@ public:
 
     virtual MOS_STATUS SubmitCommandBuffer(
         PMOS_COMMAND_BUFFER cmdBuffer,
-        bool nullRendering);
+        bool bNullRendering);
 
 #if USE_CODECHAL_DEBUG_TOOL
     MOS_STATUS DumpSegmentParams(
@@ -2393,6 +2415,8 @@ public:
     MOS_STATUS DumpPicParams(
         PCODEC_VP9_ENCODE_PIC_PARAMS picParams);
 #endif
+
+    void fill_pad_with_value(PMOS_SURFACE psSurface, uint32_t real_height, uint32_t aligned_height);
 };
 
 #endif  // __CODECHAL_VDENC_VP9_BASE_H__
