@@ -30,35 +30,4 @@
 
 #include "vp_common_hdr.h"
 
-//!
-//! Structure VPHAL_CCM_TYPE
-//! \brief Color Correction Matrix Type
-//!
-typedef enum _VPHAL_HDR_CCM_TYPE
-{
-    VPHAL_HDR_CCM_NONE = 0,
-    VPHAL_HDR_CCM_BT2020_TO_BT601_BT709_MATRIX,
-    VPHAL_HDR_CCM_BT601_BT709_TO_BT2020_MATRIX,
-    VPHAL_HDR_CCM_BT2020_TO_MONITOR_MATRIX,
-    VPHAL_HDR_CCM_MONITOR_TO_BT2020_MATRIX,
-    VPHAL_HDR_CCM_MONITOR_TO_BT709_MATRIX
-} VPHAL_HDR_CCM_TYPE;
-
-
-//!
-//! Structure VPHAL_CSC_TYPE
-//! \brief Color Space Coversion Type
-//!
-typedef enum _VPHAL_HDR_CSC_TYPE
-{
-    VPHAL_HDR_CSC_NONE = 0,
-    VPHAL_HDR_CSC_YUV_TO_RGB_BT601,
-    VPHAL_HDR_CSC_YUV_TO_RGB_BT709,
-    VPHAL_HDR_CSC_YUV_TO_RGB_BT2020,
-    VPHAL_HDR_CSC_RGB_TO_YUV_BT601,
-    VPHAL_HDR_CSC_RGB_TO_YUV_BT709,
-    VPHAL_HDR_CSC_RGB_TO_YUV_BT709_FULLRANGE,
-    VPHAL_HDR_CSC_RGB_TO_YUV_BT2020
-} VPHAL_HDR_CSC_TYPE;
-
 #endif  // __VPHAL_COMMON_HDR_H__
