@@ -27,6 +27,7 @@
 //!
 
 #include "codechal_decode_hevc_long_g12.h"
+#include "mos_os_cp_interface_specific.h"
 
 // HEVC Long format 
 HevcDecodeSliceLongG12::HevcDecodeSliceLongG12(
@@ -38,6 +39,8 @@ HevcDecodeSliceLongG12::HevcDecodeSliceLongG12(
     m_hcpInterface = static_cast<MhwVdboxHcpInterfaceG12*>(hcpInterface);
     m_miInterface = miInterface;
     m_osInterface  = m_decoder->GetOsInterface();
+    m_hwInterface    = decoder->GetHwInterface();
+    m_vdencInterface = m_hwInterface->GetVdencInterface();
 
     //copy other params from decoder
     m_numSlices = m_decoder->m_numSlices;
@@ -78,6 +81,7 @@ MOS_STATUS HevcDecodeSliceLongG12::ProcessSliceLong(uint8_t *cmdResBase, uint32_
     auto slc = m_hevcSliceParams;
     auto slcBase = slc;
     auto slcExt = m_hevcExtSliceParams;
+    auto pic = m_hevcPicParams;
 
     PMOS_COMMAND_BUFFER cmdBufArray, cmdBuf;
 
@@ -106,10 +110,27 @@ MOS_STATUS HevcDecodeSliceLongG12::ProcessSliceLong(uint8_t *cmdResBase, uint32_
         PHEVC_SLICE_TILE_PARAMS     sliceTileParams = nullptr;
 
         bool isIndependentSlice = (i == 0) || !slc->LongSliceFlags.fields.dependent_slice_segment_flag;
+
+        if(slc->slice_data_offset + slc->slice_data_size > m_decoder->m_dataSize)
+        {
+            CODECHAL_DECODE_ASSERTMESSAGE("invalid slice %d, data size overflow\n", i);
+            MOS_SafeFreeMemory(cmdBufArray);
+            return MOS_STATUS_INVALID_PARAMETER;
+        }
+
         if (isIndependentSlice)
         {
             origCtbX = slc->slice_segment_address % m_widthInCtb;
             origCtbY = slc->slice_segment_address / m_widthInCtb;
+
+            if(i == 0 && slc->slice_segment_address != 0)
+            {
+                //Spec reequires that segment address in first slice must be 0
+                CODECHAL_DECODE_ASSERTMESSAGE("invalid independent slice %d, slice_segment_address=%d\n",
+                    i, slc->slice_segment_address);
+                MOS_SafeFreeMemory(cmdBufArray);
+                return MOS_STATUS_INVALID_PARAMETER;
+            }
         }
         else //dependent
         {
@@ -120,11 +141,25 @@ MOS_STATUS HevcDecodeSliceLongG12::ProcessSliceLong(uint8_t *cmdResBase, uint32_
                 {
                     origCtbX = (slcBase + index)->slice_segment_address % m_widthInCtb;
                     origCtbY = (slcBase + index)->slice_segment_address / m_widthInCtb;
+
+                    if(index == 0 && (slcBase + index)->slice_segment_address != 0)
+                    {
+                        CODECHAL_DECODE_ASSERTMESSAGE("invalid dependent slice %d, index %d, slice_segment_address=%d\n",
+                            index, slc->slice_segment_address);
+                        MOS_SafeFreeMemory(cmdBufArray);
+                        return MOS_STATUS_INVALID_PARAMETER;
+                    }
                     break;
                 }
             }
         }
 
+        if (m_hevcRefList[pic->CurrPic.FrameIdx]->bIsIntra &&
+            !m_hcpInterface->IsHevcISlice(slc->LongSliceFlags.fields.slice_type))
+        {
+            slc->LongSliceFlags.fields.slice_temporal_mvp_enabled_flag = 0;
+        }
+
         if (m_isSeparateTileDecoding || m_isRealTile)
         {
             tileX = GetSliceTileX(slc);
@@ -184,6 +219,7 @@ MOS_STATUS HevcDecodeSliceLongG12::ProcessSliceLong(uint8_t *cmdResBase, uint32_
                 if (eStatus != MOS_STATUS_SUCCESS)
                 {
                     MOS_SafeFreeMemory(sliceTileParams);
+                    MOS_SafeFreeMemory(cmdBufArray);
                     CODECHAL_DECODE_CHK_STATUS_RETURN(eStatus);
                 }
                 //insert 2 dummy VD_CONTROL_STATE packets with data=0 before every HCP_TILE_CODING
@@ -206,6 +242,7 @@ MOS_STATUS HevcDecodeSliceLongG12::ProcessSliceLong(uint8_t *cmdResBase, uint32_
                 if (eStatus != MOS_STATUS_SUCCESS)
                 {
                     MOS_SafeFreeMemory(sliceTileParams);
+                    MOS_SafeFreeMemory(cmdBufArray);
                     CODECHAL_DECODE_CHK_STATUS_RETURN(eStatus);
                 }
 
@@ -253,6 +290,7 @@ MOS_STATUS HevcDecodeSliceLongG12::ProcessSliceLong(uint8_t *cmdResBase, uint32_
             if (eStatus != MOS_STATUS_SUCCESS)
             {
                 MOS_SafeFreeMemory(sliceTileParams);
+                MOS_SafeFreeMemory(cmdBufArray);
                 CODECHAL_DECODE_CHK_STATUS_RETURN(eStatus);
             }
 
@@ -260,6 +298,7 @@ MOS_STATUS HevcDecodeSliceLongG12::ProcessSliceLong(uint8_t *cmdResBase, uint32_
             if (eStatus != MOS_STATUS_SUCCESS)
             {
                 MOS_SafeFreeMemory(sliceTileParams);
+                MOS_SafeFreeMemory(cmdBufArray);
                 CODECHAL_DECODE_CHK_STATUS_RETURN(eStatus);
             }
 
@@ -267,6 +306,7 @@ MOS_STATUS HevcDecodeSliceLongG12::ProcessSliceLong(uint8_t *cmdResBase, uint32_
             if (eStatus != MOS_STATUS_SUCCESS)
             {
                 MOS_SafeFreeMemory(sliceTileParams);
+                MOS_SafeFreeMemory(cmdBufArray);
                 CODECHAL_DECODE_CHK_STATUS_RETURN(eStatus);
             }
 
@@ -274,9 +314,35 @@ MOS_STATUS HevcDecodeSliceLongG12::ProcessSliceLong(uint8_t *cmdResBase, uint32_
             if (eStatus != MOS_STATUS_SUCCESS)
             {
                 MOS_SafeFreeMemory(sliceTileParams);
+                MOS_SafeFreeMemory(cmdBufArray);
                 CODECHAL_DECODE_CHK_STATUS_RETURN(eStatus);
             }
 
+            if (MEDIA_IS_WA(m_waTable, Wa_2209620131) && m_isRealTile)
+            {
+                // Send MFX_WAIT command
+                eStatus = (MOS_STATUS)(m_miInterface->AddMfxWaitCmd(cmdBuf, nullptr, true));
+                if (eStatus != MOS_STATUS_SUCCESS)
+                {
+                    MOS_SafeFreeMemory(sliceTileParams);
+                    MOS_SafeFreeMemory(cmdBufArray);
+                    CODECHAL_DECODE_CHK_STATUS_RETURN(eStatus);
+                }
+                // Send VD_PIPELINE_FLUSH command
+                MHW_VDBOX_VD_PIPE_FLUSH_PARAMS vdPipelineFlushParams;
+                MOS_ZeroMemory(&vdPipelineFlushParams, sizeof(vdPipelineFlushParams));
+                vdPipelineFlushParams.Flags.bWaitDoneHEVC           = 1;
+                vdPipelineFlushParams.Flags.bFlushHEVC              = 1;
+                vdPipelineFlushParams.Flags.bWaitDoneVDCmdMsgParser = 1;
+                eStatus = (MOS_STATUS)(m_vdencInterface->AddVdPipelineFlushCmd(cmdBuf, &vdPipelineFlushParams));
+                if (eStatus != MOS_STATUS_SUCCESS)
+                {
+                    MOS_SafeFreeMemory(sliceTileParams);
+                    MOS_SafeFreeMemory(cmdBufArray);
+                    CODECHAL_DECODE_CHK_STATUS_RETURN(eStatus);
+                }
+            }
+
             if (++tileX > m_hevcPicParams->num_tile_columns_minus1)
             {
                 tileX = 0;  ++tileY;
@@ -298,9 +364,15 @@ MOS_STATUS HevcDecodeSliceLongG12::ProcessSliceLong(uint8_t *cmdResBase, uint32_
 
     for (int i = 0; i < cmdBufArraySize; i++)
     {
-        CODECHAL_DECODE_CHK_STATUS_RETURN(m_miInterface->AddMiBatchBufferEnd(
+        eStatus = (MOS_STATUS)m_miInterface->AddMiBatchBufferEnd(
             &cmdBufArray[i],
-            nullptr));
+            nullptr);
+
+        if (eStatus != MOS_STATUS_SUCCESS)
+        {
+            MOS_SafeFreeMemory(cmdBufArray);
+            CODECHAL_DECODE_CHK_STATUS_RETURN(eStatus);
+        }
     }
 
     if (cmdBufArray)
