@@ -116,7 +116,7 @@
 #endif
 #ifdef _HEVC_ENCODE_VDENC_SUPPORTED
 #include "codechal_vdenc_hevc_xe_xpm.h"
-#ifdef _APOGEIOS_SUPPORTED
+#ifdef _MEDIA_RESERVED
 #include "decode_hevc_pipeline_adapter_m12.h"
 #endif
 #endif
@@ -133,7 +133,7 @@
 #ifdef _VP9_ENCODE_VDENC_SUPPORTED
 #include "codechal_vdenc_vp9_g12.h"
 #include "codechal_vdenc_vp9_xe_hpm.h"
-#ifdef _APOGEIOS_SUPPORTED
+#ifdef _MEDIA_RESERVED
 #include "encode_vp9_vdenc_pipeline_adapter_xe_xpm.h"
 #endif
 #endif
@@ -198,9 +198,8 @@ public:
     using Mcpy  = MediaCopyStateXe_Xpm_Base;
 
     MOS_STATUS Initialize(
-        PMOS_INTERFACE osInterface,
-        MhwInterfaces *mhwInterfaces);
-
+        PMOS_INTERFACE osInterface);
+protected:
     MhwInterfaces* CreateMhwInterface(
         PMOS_INTERFACE osInterface);
 };
