@@ -50,7 +50,6 @@ public:
     virtual MOS_STATUS CreateSfcRender(SfcRenderBase *&sfcRender, VP_MHWINTERFACE &vpMhwinterface, PVpAllocator allocator);
     virtual VpCmdPacket *CreateRenderPacket(MediaTask * task, _VP_MHWINTERFACE *hwInterface, VpAllocator *&allocator, VPMediaMemComp *mmc, VpKernelSet* kernel);
     virtual MediaCopyBaseState* CreateMediaCopy();
-    virtual VpKernelConfig &GetKernelConfig();
 
     virtual MOS_STATUS VeboxQueryStatLayout(
         VEBOX_STAT_QUERY_TYPE queryType,
@@ -80,6 +79,16 @@ public:
         return false;
     }
 
+    virtual bool IsDecompForInterlacedSurfWaEnabled()
+    {
+        return true;
+    }
+
+    virtual bool IsLegacyEuCountInUse()
+    {
+        return true;
+    }
+
     virtual MOS_STATUS GetInputFrameWidthHeightAlignUnit(
         PVP_MHWINTERFACE          pvpMhwInterface,
         uint32_t                 &widthAlignUnit,
@@ -102,6 +111,8 @@ public:
         return true;
     }
 
+    virtual MOS_STATUS InitVpFeatureSupportBits() override;
+
 protected:
     bool m_disableSfcDithering = false;
 
