@@ -51,8 +51,8 @@ class DecodeAv1FeatureManagerG12_Base : public DecodeFeatureManager
         //! \param  [in] recycleBuf
         //!         Pointer to RecycleResource
         //!
-        DecodeAv1FeatureManagerG12_Base(DecodeAllocator *allocator, CodechalHwInterface *hwInterface)
-            : DecodeFeatureManager(allocator, hwInterface)
+        DecodeAv1FeatureManagerG12_Base(DecodeAllocator *allocator, void *hwInterface, PMOS_INTERFACE osInterface)
+            : DecodeFeatureManager(allocator, hwInterface, osInterface)
         {}
 
         //!
@@ -70,7 +70,7 @@ class DecodeAv1FeatureManagerG12_Base : public DecodeFeatureManager
         //!         MOS_STATUS_SUCCESS if success, else fail reason
         //!
         virtual MOS_STATUS CreateFeatures(void *codecSettings);
-    MEDIA_CLASS_DEFINE_END(DecodeAv1FeatureManagerG12_Base)
+    MEDIA_CLASS_DEFINE_END(decode__DecodeAv1FeatureManagerG12_Base)
     };
 
 }
