@@ -33,11 +33,10 @@ namespace encode {
 
 MOS_STATUS JpegPipelineXe_Lpm_Plus_Base::InitMmcState()
 {
-#ifdef _MMC_SUPPORTED
     ENCODE_CHK_NULL_RETURN(m_hwInterface);
     m_mmcState = MOS_New(EncodeMemCompXe_Lpm_Plus_Base, m_hwInterface);
     ENCODE_CHK_NULL_RETURN(m_mmcState);
-#endif
+
     return MOS_STATUS_SUCCESS;
 }
 
