@@ -45,44 +45,13 @@ MediaScalability::MediaScalability(MediaContext *mediaContext) :
 
 bool MediaScalability::IsScalabilityModeMatched(ScalabilityPars *params)
 {
-    bool isMatched = false;
-
-
-#if (_DEBUG || _RELEASE_INTERNAL)
-
-    if (m_osInterface == nullptr)
-    {
-        return false;
-    }
-    if (m_osInterface->bEnableDbgOvrdInVE)
-    {
-        isMatched = true;
-    }
-    else
-#endif
-    {
-        isMatched = m_scalabilityOption->IsScalabilityOptionMatched(params);
-    }
-
-    return isMatched;
+    return m_scalabilityOption->IsScalabilityOptionMatched(params);
 }
 
 bool MediaScalability::IsScalabilityModeMatched(MediaScalabilityOption &scalabOption)
 {
-#if (_DEBUG || _RELEASE_INTERNAL)
-    if (m_osInterface == nullptr)
-    {
-        return false;
-    }
-    if (m_osInterface->bEnableDbgOvrdInVE)
-    {
-        return true;
-    }
-    else
-#endif
-    {
-        return m_scalabilityOption->IsScalabilityOptionMatched(scalabOption);
-    }
+
+    return m_scalabilityOption->IsScalabilityOptionMatched(scalabOption);
 }
 
 bool MediaScalability::IsGpuCtxCreateOptionMatched(PMOS_GPUCTX_CREATOPTIONS_ENHANCED gpuCtxCreateOption1, PMOS_GPUCTX_CREATOPTIONS_ENHANCED gpuCtxCreateOption2)
@@ -176,8 +145,9 @@ MOS_STATUS MediaScalability::Destroy()
     {
         if (m_veState)
         {
-            SCALABILITY_CHK_STATUS_RETURN(MosInterface::SetVirtualEngineState(m_osInterface->osStreamState, m_veState));
-            return MosInterface::DestroyVirtualEngineState(m_osInterface->osStreamState);
+            SCALABILITY_CHK_NULL_RETURN(m_osInterface->osStreamState);
+            m_osInterface->osStreamState->virtualEngineInterface = m_veState;
+            return m_osInterface->pfnDestroyVirtualEngineState(m_osInterface->osStreamState);
         }
 
         // No VE state to destroy in some scalability instances
