@@ -205,6 +205,8 @@ struct VP_POLICY_RULES
 
     bool isAvsSamplerSupported;
     bool isHDR3DLutKernelEnabled;
+    bool is1K1DLutSurfaceInUse;
+    bool isHDR33LutSizeEnabled = false;
 };
 
 struct VP_HW_CAPS
