@@ -500,7 +500,8 @@ using PRENDER_OCL_FC_PARAMS = RENDER_OCL_FC_PARAMS *;
 
 struct AI_KERNEL_CONFIG
 {
-    VPHAL_PERFTAG            perfTag     = VPHAL_NONE;
+    VPHAL_PERFTAG perfTag     = VPHAL_NONE;
+    FeatureType   featureType = FeatureTypeInvalid;
 };
 
 struct AI_KERNEL_PARAM
@@ -509,6 +510,7 @@ struct AI_KERNEL_PARAM
     std::string                  kernelName;
     uint32_t                     threadWidth;
     uint32_t                     threadHeight;
+    uint32_t                     threadDepth;
     uint32_t                     localWidth;
     uint32_t                     localHeight;
     KERNEL_ARG_INDEX_SURFACE_MAP kernelStatefulSurfaces;
