@@ -51,11 +51,14 @@ public:
         return MOS_STATUS_SUCCESS;
     }
 
+    virtual void OcaDumpKernelInfo(MOS_COMMAND_BUFFER &cmdBuffer, MOS_CONTEXT &mosContext) override;
+
 protected:
     virtual MOS_STATUS SetupSurfaceState() override;
     virtual MOS_STATUS SetWalkerSetting(KERNEL_THREAD_SPACE &threadSpace, bool bSyncFlag, bool flushL1 = false);
     virtual MOS_STATUS SetKernelArgs(KERNEL_ARGS &kernelArgs, VP_PACKET_SHARED_CONTEXT *sharedContext);
-    virtual MOS_STATUS SetupStatelessBuffer() override;
+    virtual MOS_STATUS GetKernelSurfaceParam(bool isBTI, SURFACE_PARAMS &surfParam, KERNEL_SURFACE_STATE_PARAM &kernelSurfaceParam);
+    virtual MOS_STATUS GetInlineData(uint8_t *inlineData);
 
     PRENDERHAL_INTERFACE m_renderHal = nullptr;
 
@@ -66,10 +69,10 @@ protected:
     KERNEL_INDEX_ARG_MAP         m_kernelArgs          = {};
     KERNEL_BTIS                  m_kernelBtis          = {};
     KRN_EXECUTE_ENV              m_kernelEnv           = {};
+    KRN_PER_THREAD_ARG_INFO      m_kernelPerThreadArgInfo = {};
     KERNEL_WALKER_PARAMS         m_walkerParam         = {};
     void                        *m_curbe               = nullptr;
     uint32_t                     m_kernelIndex         = 0;
-    uint32_t                     m_curbeSize           = 0;
     int32_t                      m_linearSamplerIndex  = -1;
     int32_t                      m_nearestSamplerIndex = -1;
     std ::vector<uint8_t>        m_inlineData          = {};
