@@ -457,6 +457,26 @@ public:
     //! \return   MOS_STATUS
     //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
     //!
+    virtual MOS_STATUS SetVeboxCSCParams(PVEBOX_CSC_PARAMS cscParams) override;
+
+    //!
+    //! \brief    Setup CSC Params for Vebox front end
+    //! \details  Setup surface CSC Params for Vebox
+    //! \param    [in] cscParams
+    //!           CSC Params
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+    //!
+    virtual MOS_STATUS SetVeboxFeCSCParams(PVEBOX_CSC_PARAMS cscParams) override;
+
+     //!
+    //! \brief    Setup CSC Params for Vebox
+    //! \details  Setup surface CSC Params for Vebox
+    //! \param    [in] cscParams
+    //!           CSC Params
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+    //!
     virtual MOS_STATUS SetVeboxBeCSCParams(PVEBOX_CSC_PARAMS cscParams) override;
 
     //!
@@ -917,6 +937,20 @@ public:
     //!
     virtual MOS_STATUS AdjustBlockStatistics();
 
+    //!
+    //! \brief    Get VeBox 3DLut interpolation method
+    //! \details  Get VeBox 3DLut interpolation method
+    //! \param    VPHAL_3DLUT_INTERPOLATION interpolationMethod
+    //!           [in] 3DLUT interpolation method
+    //! \return   MHW_3DLUT_INTERPOLATION
+    //!           Return 3DLUT interpolation method
+    //!
+    virtual MHW_3DLUT_INTERPOLATION Get3DLutInterpolationMethod(
+        VPHAL_3DLUT_INTERPOLATION       interpolationMethod)
+    {
+        return MHW_3DLUT_INTERPOLATION_TRILINEAR;
+    }
+
     virtual MOS_STATUS GNELumaConsistentCheck(
         uint32_t &dwGNELuma,
         uint32_t *pStatSlice0GNEPtr,
@@ -951,6 +985,14 @@ public:
     {
         return MOS_STATUS_SUCCESS;
     }
+
+    virtual MOS_STATUS StoreCSEngineIdRegMem(
+        MOS_COMMAND_BUFFER *cmdBuffer,
+        const MHW_VEBOX_HEAP *veboxHeap)
+    {
+        return MOS_STATUS_SUCCESS;
+    }
+
 #endif
 
 protected:
