@@ -113,7 +113,7 @@ VAStatus DdiEncodeAV1::ContextInitialize(
     DDI_CODEC_CHK_NULL(m_encodeCtx->pEncodeStatusReport, "nullptr m_encodeCtx->pEncodeStatusReport.", VA_STATUS_ERROR_ALLOCATION_FAILED);
 
     //Allocate Slice Header Data
-    m_encodeCtx->pSliceHeaderData = (CODEC_ENCODER_SLCDATA *)MOS_AllocAndZeroMemory(MAX_NUM_OBU_TYPES * sizeof(CODEC_ENCODER_SLCDATA));
+    m_encodeCtx->pSliceHeaderData = (CODEC_ENCODER_SLCDATA *)MOS_AllocAndZeroMemory(ENCODE_VDENC_AV1_MAX_TILE_GROUP_NUM * sizeof(CODEC_ENCODER_SLCDATA));
     DDI_CODEC_CHK_NULL(m_encodeCtx->pSliceHeaderData, "nullptr m_encodeCtx->pSliceHeaderData.", VA_STATUS_ERROR_ALLOCATION_FAILED);
 
     // Create the bit stream buffer to hold the packed headers from application
@@ -396,7 +396,21 @@ VAStatus DdiEncodeAV1::ParseSeqParams(void *ptr)
     av1SeqParams->GopPicSize    = seqParams->intra_period;
     av1SeqParams->GopRefDist    = seqParams->ip_period;
  
-    av1SeqParams->RateControlMethod = VARC2HalRC(m_encodeCtx->uiRCMethod);
+    switch ((uint32_t)m_encodeCtx->uiRCMethod)
+    {
+    case VA_RC_TCBRC:
+    case VA_RC_VBR:
+        av1SeqParams->RateControlMethod = (uint8_t)RATECONTROL_VBR;
+        break;
+    case VA_RC_CQP:
+        av1SeqParams->RateControlMethod = (uint8_t)RATECONTROL_CQP;
+        break;
+    case VA_RC_ICQ:
+        av1SeqParams->RateControlMethod = (uint8_t)RATECONTROL_CQL;
+        break;
+    default:
+        av1SeqParams->RateControlMethod = (uint8_t)RATECONTROL_CBR;
+    }
 
     /* the bits_per_second is only used when the target bit_rate is not initialized */
     if (av1SeqParams->TargetBitRate[0] == 0)
@@ -421,7 +435,7 @@ VAStatus DdiEncodeAV1::ParseSeqParams(void *ptr)
 #else
     av1SeqParams->SeqFlags.fields.HierarchicalFlag = seqParams->reserved8b;
 #endif
-
+    av1SeqParams->SeqFlags.fields.DisplayFormatSwizzle = NeedDisplayFormatSwizzle(m_encodeCtx->RTtbl.pCurrentRT);
     return VA_STATUS_SUCCESS;
 }
 
@@ -532,6 +546,7 @@ VAStatus DdiEncodeAV1::ParsePicParams(DDI_MEDIA_CONTEXT *mediaCtx, void *ptr)
     av1PicParams->PicFlags.fields.LongTermReference            = picParams->picture_flags.bits.long_term_reference;
     av1PicParams->PicFlags.fields.DisableFrameRecon            = picParams->picture_flags.bits.disable_frame_recon;
     av1PicParams->PicFlags.fields.PaletteModeEnable            = picParams->picture_flags.bits.palette_mode_enable;
+    av1PicParams->PicFlags.fields.allow_intrabc                = picParams->picture_flags.bits.allow_intrabc;
     av1PicParams->PicFlags.fields.SegIdBlockSize               = picParams->seg_id_block_size;
 
 #if VA_CHECK_VERSION(1, 16, 0)
@@ -904,7 +919,10 @@ VAStatus DdiEncodeAV1::ParseMiscParamRC(void *data)
 
     if (VA_RC_CBR == m_encodeCtx->uiRCMethod)
     {
-        seqParams->TargetBitRate[temporalId] = bitRate * vaEncMiscParamRC->target_percentage / 100;
+        if(vaEncMiscParamRC->target_percentage != 0)
+            seqParams->TargetBitRate[temporalId] = bitRate * vaEncMiscParamRC->target_percentage / 100;
+        else
+            seqParams->TargetBitRate[temporalId] = bitRate;
         seqParams->MaxBitRate                = seqParams->TargetBitRate[temporalId];
         seqParams->MinBitRate                = seqParams->TargetBitRate[temporalId];
         seqParams->RateControlMethod         = RATECONTROL_CBR;
@@ -919,7 +937,10 @@ VAStatus DdiEncodeAV1::ParseMiscParamRC(void *data)
     }
     else if (VA_RC_VBR == m_encodeCtx->uiRCMethod)
     {
-        seqParams->TargetBitRate[temporalId] = bitRate * vaEncMiscParamRC->target_percentage / 100; //VBR target bits;
+        if(vaEncMiscParamRC->target_percentage != 0)
+            seqParams->TargetBitRate[temporalId] = bitRate * vaEncMiscParamRC->target_percentage / 100;
+        else
+            seqParams->TargetBitRate[temporalId] = bitRate;
         seqParams->MaxBitRate = bitRate;
         seqParams->MinBitRate = 0;
         seqParams->RateControlMethod = RATECONTROL_VBR;
@@ -935,6 +956,19 @@ VAStatus DdiEncodeAV1::ParseMiscParamRC(void *data)
             savedMaxBitRate[temporalId] = bitRate;
         }
     }
+    else if (VA_RC_ICQ == m_encodeCtx->uiRCMethod)
+    {   
+        seqParams->RateControlMethod = RATECONTROL_CQL;
+        seqParams->ICQQualityFactor = vaEncMiscParamRC->quality_factor;
+        if (savedQualityFactor != seqParams->ICQQualityFactor)
+        {
+            if (savedQualityFactor != 0)
+            {
+                seqParams->SeqFlags.fields.ResetBRC |= 0x01;
+            }
+            savedQualityFactor = seqParams->ICQQualityFactor;
+        }
+    }
 
     /* the reset flag in RC will be considered. */
     seqParams->SeqFlags.fields.ResetBRC |= vaEncMiscParamRC->rc_flags.bits.reset;
@@ -1121,10 +1155,10 @@ uint32_t DdiEncodeAV1::getSliceParameterBufferSize()
 }
 
 
-CODECHAL_FUNCTION DdiEncodeAV1::GetEncodeCodecFunction(VAProfile profile, VAEntrypoint entrypoint)
+CODECHAL_FUNCTION DdiEncodeAV1::GetEncodeCodecFunction(VAProfile profile, VAEntrypoint entrypoint, bool bVDEnc)
 {
     CODECHAL_FUNCTION codecFunction = CODECHAL_FUNCTION_INVALID;
-   if (entrypoint == VAEntrypointEncSliceLP)
+    if (bVDEnc)
     {
         codecFunction = CODECHAL_FUNCTION_ENC_VDENC_PAK;
     }
@@ -1142,6 +1176,7 @@ CODECHAL_MODE DdiEncodeAV1::GetEncodeCodecMode(
     switch (profile)
     {
     case VAProfileAV1Profile0:
+    case VAProfileAV1Profile1:
         return CODECHAL_ENCODE_MODE_AV1;
     default:
         DDI_CODEC_ASSERTMESSAGE("Unsuported CODECHAL_MODE");
